# Distances Calculator

This is a distance calculator between 2 addressed, it is based on 
*openstreetmap* api.

## Getting start

### requirements


### get distance between 2 addresses


### calculate the distance between a table's data

## How to calculate distance
### Based on coordinate
Earth is a sphere, so we can use simple triangle function to 
calculate a not accurate distance, but most of time, 
this direct distance is good enough.

### Based on open street map api (in future)
this can be used to calculate route distance.

## API
